#!/bin/bash

# Set environment variables and call do-*.sh in sequence

[ -z "$WEBDIR" ] && export WEBDIR=~/www/kdocs
[ -z "$LNXDIR" ] && export LNXDIR=~/linux/linux

source "$WEBDIR"/make/functions.sh

# Update mercurial repository
#if [ "$1" != "--nonet" ]
#then
#  echo "Update Linux source from mercurial on kernel.org"
#  get_git || exit 1
#else
#  shift
#fi

echo "Set up Linux build directory"
setuplinuxtemp || exit 1

if [ "$1" == "--long" ]
then
  # I have a dual processor laptop, so overlap work here.  Have make htmldocs
  # produce split-up versions in the background (which is very slow)
  # while other work is done in the foreground.
  make_htmldocs > /dev/null 2>/dev/null &
fi

echo "Install and index Documentation directory."
update_documentation_dir || exit 1

echo "Update master index."
update_master || exit 1

echo "Mirror resources"
mirror_files || exit 1

echo Copy readme files from Linux kernel
find_readmes || exit 1

echo Convert kconfig to html for all architectures
htmlize_menuconfig || exit 1

# Install the htmldocs
if [ "$1" == "--long" ]
then
  echo Build nochunks htmldocs.
  make_htmlnochunks || exit 1

  echo Search for references to RFC documents
  findrfc || exit 1

  # Wait for background task(s) to finish.  If there aren't any, this continues
  # immediately.
  wait4background

  # Install the htmldocs
  install_htmldocs || exit 1
fi

echo "Done with kdocs"
